@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Logging facilities
 
@@ -12,7 +12,7 @@ David Malcolm <dmalcolm@redhat.com>
 import os
 import time
 import datetime
-from config import Config
+from config import config
 
 # Timestamp class for file logs
 class TimeStamp:
@@ -23,38 +23,45 @@ class TimeStamp:
 		self.now = "0"
 		self.timetup = time.localtime()
 	
-	def zeroPad(self, int, width = 1):
+	def zeroPad(self, int, width = 2):
 		"""
 		Pads an integer 'int' with zeroes, up to width 'width'.
+		
 		Returns a string.
+		
+		It will not truncate. If you call zeroPad(100, 2), '100' will be returned.
 		"""
 		if int < 10 ** width:
-			return ("0" * width) + str(int)
+			return ("0" * (width - len(str(int))) ) + str(int)
 		else: 
 			return str(int)
 
 	# file stamper
-	def fileStamp(self, filename):
+	def fileStamp(self, filename, addTime = True):
 		"""
-		Generates a temp filename of YYYYMMDD. If the file already exists, it appends a .0 and will increment by 1 until there is a unique name
+		Generates a filename stamp in the format of filename_YYYYMMDD-hhmmss.
+		A format of filename_YYYYMMDD can be used instead by specifying addTime = False.
 		"""
-		self.now = filename.strip() + "-"
+		self.now = filename.strip() + "_"
 		self.timetup = time.localtime()
 
 		# Should produce rel-eng style filestamps
 		# format it all pretty by chopping the tuple
-		for i in range(3):
+		fieldCount = 3
+		if addTime: fieldCount = fieldCount + 3
+		for i in range(fieldCount):
+			if i == 3: self.now = self.now + '-'
 			self.now = self.now + self.zeroPad(self.timetup[i])
 		return self.now
 
 	# Log entry stamper
 	def entryStamp(self):
 		"""
-		Generates a logfile entry stamp of YYYYMMDD HH:MM:SS
+		Generates a logfile entry stamp of YYYY.MM.DD HH:MM:SS
 		"""
 		self.timetup = time.localtime()
 
-		# This will return a log entry formatted string in YYYY.MM.DD  HH:MM:SS
+		# This will return a log entry formatted string in YYYY.MM.DD HH:MM:SS
 		for i in range(6):
 			# put in the year
 			if i == 0:
@@ -80,18 +87,18 @@ class LogWriter:
 	"""
 	def __init__(self):
 		self.entry = {}
-		# Set the logdir - maybe we want to use mktemp(1) for this later.
-		self.logdir = Config.logdir #'/tmp/dogtail-' + os.environ['LOGNAME'] + '/'
-		if not os.path.isdir(self.logdir): os.makedirs(self.logdir)
+		# Set the logDir - maybe we want to use mktemp(1) for this later.
+		self.logDir = config.logDir #'/tmp/dogtail-' + os.environ['LOGNAME'] + '/'
+		if not os.path.isdir(self.logDir): os.makedirs(self.logDir)
 		self.logfile = ''
-		self.scriptname = Config.scriptname 
-		if not self.scriptname: self.scriptname = 'log'
+		self.scriptName = config.scriptName 
+		if not self.scriptName: self.scriptName = 'log'
 		self.loghandle = "" # Handle to the logfile
 		self.stamper = TimeStamp()
-		# check to see if we can write to the logdir
-		if os.path.isdir(self.logdir):
+		# check to see if we can write to the logDir
+		if os.path.isdir(self.logDir):
 			# generate a logfile name and check if it already exists
-			self.logfile = self.logdir + self.stamper.fileStamp(self.scriptname)
+			self.logfile = self.logDir + self.stamper.fileStamp(self.scriptName)
 			i = 0
 			while os.path.exists(self.logfile):
 				# Append the pathname
@@ -104,13 +111,14 @@ class LogWriter:
 				i += 1
 		else:
 			# If path doesn't exist, raise an exception
-			raise IOError, "Log path %s does not exist or is not a directory" % self.logdir
+			raise IOError, "Log path %s does not exist or is not a directory" % self.logDir
 
 		# Try to create the file and write the header info
 		try:
+			print "Creating logfile at %s ..." % self.logfile
 			date = datetime.datetime.strftime(datetime.datetime.now(), '%d %b %Y %H:%M:%S')
 			self.loghandle = open(self.logfile, 'w')
-			self.loghandle.write("##### " + self.scriptname + " Created on: " + date + "\n")
+			self.loghandle.write("##### " + self.scriptName + " Created on: " + date + "\n")
 			self.loghandle.flush()
 			self.loghandle.close()
 		except IOError:
@@ -147,12 +155,44 @@ class LogWriter:
 		except IOError:
 			print "Could not write to file " + self.logfile
 
+class IconLogger:
+	"""
+	Writes entries to the tooltip of an icon in the notification area or the desktop.
+	"""
+	trayicon = None
+	def __init__(self, config = None, module_list = None):
+		if not IconLogger.trayicon:
+			from trayicon import TrayIcon
+			IconLogger.trayicon = TrayIcon()
+			if IconLogger.trayicon.proc: self.works = True
+			else: self.works = False
+			iconName = 'dogtail-tail-48.png'
+			iconPath = '/usr/share/icons/hicolor/48x48/apps/' + iconName
+			if os.path.exists(iconPath):
+				IconLogger.trayicon.set_icon(iconPath)
+			self.message('dogtail running...')
+
+	def message(self, msg):
+		"""
+		Display a message to the user
+		"""
+		IconLogger.trayicon.set_tooltip(msg)
+
 class DebugLogger:
+	"""
+	Writes entries to standard out, and to an IconLogger if possible.
+	"""
+	def __init__(self):
+		self.iconLogger = IconLogger()
+
 	def log(self, message):
 		"""
-		Hook used for logging messages.  Might eventually be a virtual
+		Hook used for logging messages. Might eventually be a virtual
 		function, but nice and simple for now.
 		"""
+		# Try to use the IconLogger.
+		if self.iconLogger.works: self.iconLogger.message(message)
+		# Also write to standard out.
 		print message
 
 debugLogger = DebugLogger()
