@@ -5,6 +5,13 @@ __author__ = 'David Malcolm <dmalcolm@redhat.com>'
 
 import unittest
 
+from i18n import TranslatableString
+
+def stringMatches(scriptName, reportedName):
+	assert isinstance(scriptName, TranslatableString)
+	
+	return scriptName.matchedBy(reportedName)
+	
 def makeScriptRecursiveArgument(isRecursive, defaultValue):
 	if isRecursive==defaultValue:
 		return ""
@@ -15,6 +22,7 @@ def makeCamel(string):
 	"""
 	Convert string to camelCaps
 	"""
+	string = str(string)
 	# FIXME: this function is probably really fragile, lots of difficult cases here
 
 	# Sanitize string, replacing bad characters with spaces:
@@ -77,16 +85,17 @@ class Predicate:
 		else:
 			return self.__dict__ == other.__dict__
 
+
 class IsAnApplicationNamed(Predicate):
 	"""Search subclass that looks for an application by name"""
 	def __init__(self, appName):
-		self.appName = appName
+		self.appName = TranslatableString(appName)
 
 	def satisfiedByNode(self, node):
-		return node.roleName=='application' and node.name==self.appName
+		return node.roleName=='application' and stringMatches(self.appName, node.name)
 
 	def describeSearchResult(self):
-		return '"%s" application'%self.appName
+		return '%s application'%self.appName
 
 	def makeScriptMethodCall(self, isRecursive):
 		# ignores the isRecursive parameter
@@ -98,21 +107,27 @@ class IsAnApplicationNamed(Predicate):
 class GenericPredicate(Predicate):
 	"""SubtreePredicate subclass that takes various optional search fields"""
 
-	def __init__(self, name = '', roleName = '', description= '', label = '', debugName=None):
-		self.name = name
+	def __init__(self, name = None, roleName = None, description= None, label = None, debugName=None):
+		if name:
+			self.name = TranslatableString(name)
+		else:
+			self.name = None
 		self.roleName = roleName
 		self.description = description
-		self.label = label
+		if label:		
+			self.label = TranslatableString(label)
+		else:
+			self.label = None
 
 		if debugName:
 			self.debugName = debugName
 		else:
 			if label:
-				self.debugName = "labelled '%s'"%label
+				self.debugName = "labelled '%s'"%self.label
 			else:
 				self.debugName = "child with"
 			if name:
-				self.debugName += " name='%s'"%name
+				self.debugName += " name=%s" % self.name
 			if roleName:
 				self.debugName += " roleName='%s'"%roleName
 			if description:
@@ -127,12 +142,12 @@ class GenericPredicate(Predicate):
 			# and then checking the label, rather than looking for a label and
 			# then returning whatever LABEL_FOR targets
 			if node.labeller:
-				return node.labeller.name==self.label
+				return stringMatches(self.label, node.labeller.name)
 			else: return False	
 		else:
 			# Ensure the node matches any criteria that were set:
 			if self.name:
-				if self.name!=node.name: return False
+				if not stringMatches(self.name,node.name): return False
 			if self.roleName:
 				if self.roleName!=node.roleName: return False
 			if self.description:
@@ -170,13 +185,13 @@ class IsNamed(Predicate):
 	"""Predicate subclass that looks simply by name"""
 
 	def __init__(self, name):
-		self.name = name
+		self.name = TranslatableString(name)
 	
 	def satisfiedByNode(self, node):
-		return node.name==self.name
+		return stringMatches(self.name, node.name)
 
 	def describeSearchResult(self):
-		return "named '%s'"%self.name
+		return "named %s"%self.name
 
 	def makeScriptMethodCall(self, isRecursive):
 		return "child(name='%s'%s)"%(self.name, makeScriptRecursiveArgument(isRecursive, True))
@@ -186,13 +201,13 @@ class IsNamed(Predicate):
 class IsAWindowNamed(Predicate):
 	"""Predicate subclass that looks for a top-level window by name"""
 	def __init__(self, windowName):
-		self.windowName = windowName
+		self.windowName = TranslatableString(windowName)
 
 	def satisfiedByNode(self, node):
-		return node.roleName=='frame' and node.name==self.windowName
+		return node.roleName=='frame' and stringMatches(self.windowName, node.name)
 
 	def describeSearchResult(self):
-		return "'%s' window"%self.windowName
+		return "%s window"%self.windowName
 
 	def makeScriptMethodCall(self, isRecursive):
 		return "window('%s'%s)"%(self.windowName, makeScriptRecursiveArgument(isRecursive, False))
@@ -211,13 +226,13 @@ class IsAWindow(Predicate):
 class IsADialogNamed(Predicate):
 	"""Predicate subclass that looks for a top-level dialog by name"""
 	def __init__(self, dialogName):
-		self.dialogName = dialogName
+		self.dialogName = TranslatableString(dialogName)
 
 	def satisfiedByNode(self, node):
-		return node.roleName=='dialog' and node.name==self.dialogName
+		return node.roleName=='dialog' and stringMatches(self.dialogName, node.name)
 
 	def describeSearchResult(self):
-		return '"%s" dialog'%self.dialogName
+		return '%s dialog'%self.dialogName
 
 	def makeScriptMethodCall(self, isRecursive):
 		return "dialog('%s'%s)"%(self.dialogName, makeScriptRecursiveArgument(isRecursive, False))
@@ -232,16 +247,16 @@ class IsLabelledBy(Predicate):
 class IsLabelledAs(Predicate):
 	"""Predicate: is this node labelled with the text string (i.e. by another node with that as a name)"""
 	def __init__(self, labelText):
-		self.labelText = labelText
+		self.labelText = TranslatableString(labelText)
 		
 	def satisfiedByNode(self, node):
 		# FIXME
 		if node.labeller:
-			return node.labeller.name==self.labelText
+			return stringMatches(self.labelText, node.labeller.name)
 		else: return False
 
 	def describeSearchResult(self):
-		return 'labelled "%s"'%self.labelText
+		return 'labelled %s'%self.labelText
 
 	def makeScriptMethodCall(self, isRecursive):
 		return "child(label='%s'%s)"%(self.labelText, makeScriptRecursiveArgument(isRecursive, True))
@@ -252,13 +267,13 @@ class IsLabelledAs(Predicate):
 class IsAMenuNamed(Predicate):
 	"""Predicate subclass that looks for a menu by name"""
 	def __init__(self, menuName):
-		self.menuName = menuName
+		self.menuName = TranslatableString(menuName)
 	
 	def satisfiedByNode(self, node):
-		return node.roleName=='menu' and node.name==self.menuName
+		return node.roleName=='menu' and stringMatches(self.menuName, node.name)
 
 	def describeSearchResult(self):
-		return '"%s" menu'%(self.menuName)
+		return '%s menu'%(self.menuName)
 
 	def makeScriptMethodCall(self, isRecursive):
 		return "menu('%s'%s)"%(self.menuName, makeScriptRecursiveArgument(isRecursive, True))
@@ -269,14 +284,14 @@ class IsAMenuNamed(Predicate):
 class IsAMenuItemNamed(Predicate):
 	"""Predicate subclass that looks for a menu item by name"""
 	def __init__(self, menuItemName):
-		self.menuItemName = menuItemName
+		self.menuItemName = TranslatableString(menuItemName)
 	
 	def satisfiedByNode(self, node):
 		roleName = node.roleName
-		return (roleName=='menu item' or roleName=='check menu item' or roleName=='radio menu item') and node.name==self.menuItemName
+		return (roleName=='menu item' or roleName=='check menu item' or roleName=='radio menu item') and stringMatches(self.menuItemName, node.name)
 
 	def describeSearchResult(self):
-		return '"%s" menuitem'%(self.menuItemName)
+		return '%s menuitem'%(self.menuItemName)
 
 	def makeScriptMethodCall(self, isRecursive):
 		return "menuItem('%s'%s)"%(self.menuItemName, makeScriptRecursiveArgument(isRecursive, True))
@@ -287,13 +302,13 @@ class IsAMenuItemNamed(Predicate):
 class IsATextEntryNamed(Predicate):
 	"""Predicate subclass that looks for a text entry by name"""
 	def __init__(self, textEntryName):
-		self.textEntryName = textEntryName
+		self.textEntryName = TranslatableString(textEntryName)
 	
 	def satisfiedByNode(self, node):
-		return node.roleName=='text' and node.name==self.textEntryName
+		return node.roleName=='text' and stringMatches(self.textEntryName, node.name)
 
 	def describeSearchResult(self):
-		return '"%s" textentry'%(self.textEntryName)
+		return '%s textentry'%(self.textEntryName)
 
 	def makeScriptMethodCall(self, isRecursive):
 		return "textentry('%s'%s)"%(self.textEntryName, makeScriptRecursiveArgument(isRecursive, True))
@@ -304,13 +319,13 @@ class IsATextEntryNamed(Predicate):
 class IsAButtonNamed(Predicate):
 	"""Predicate subclass that looks for a button by name"""
 	def __init__(self, buttonName):
-		self.buttonName = buttonName
+		self.buttonName = TranslatableString(buttonName)
 	
 	def satisfiedByNode(self, node):
-		return node.roleName=='push button' and node.name==self.buttonName
+		return node.roleName=='push button' and stringMatches(self.buttonName, node.name)
 
 	def describeSearchResult(self):
-		return '"%s" button'%(self.buttonName)
+		return '%s button'%(self.buttonName)
 
 	def makeScriptMethodCall(self, isRecursive):
 		return "button('%s'%s)"%(self.buttonName, makeScriptRecursiveArgument(isRecursive, True))
@@ -318,6 +333,23 @@ class IsAButtonNamed(Predicate):
 	def makeScriptVariableName(self):
 		return makeCamel(self.buttonName)+"Button"
 
+class IsATabNamed(Predicate):
+	"""Predicate subclass that looks for a tab by name"""
+	def __init__(self, tabName):
+		self.tabName = TranslatableString(tabName)
+	
+	def satisfiedByNode(self, node):
+		return node.roleName=='page tab' and stringMatches(self.tabName, node.name)
+
+	def describeSearchResult(self):
+		return '%s tab'%(self.tabName)
+
+	def makeScriptMethodCall(self, isRecursive):
+		return "tab('%s'%s)"%(self.tabName, makeScriptRecursiveArgument(isRecursive, True))
+
+	def makeScriptVariableName(self):
+		return makeCamel(self.tabName)+"Tab"
+
 class PredicateTests(unittest.TestCase):
 	def testCapitalization(self):
 			self.assertEquals(makeCamel("gnome-terminal"),"gnomeTerminal")
