@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """
 Handles raw input using AT-SPI event generation.
 
@@ -11,8 +11,8 @@ Zack Cerza <zcerza@redhat.com>
 """
 
 import atspi
-from tree import doDelay
-from tree import logger
+from utils import doDelay
+from logging import debugLogger as logger
 
 def click (x, y, button = 1):
 	"""
@@ -20,7 +20,7 @@ def click (x, y, button = 1):
 	"""
 	logger.log("Mouse button %s click at (%s,%s)"%(button,x,y))
 	ev = atspi.EventGenerator()
-	ev.click(x,y,button)
+	ev.click(x, y, button)
 	doDelay()
 	
 def doubleClick (x, y, button = 1):
@@ -87,3 +87,26 @@ def drag(fromXY, toXY, button = 1):
 	ev.release (x, y, button)
 	doDelay()
 
+def typeText(string):
+	"""
+	Types the specified string, one character at a time.
+	"""
+	ev = atspi.EventGenerator()
+	ev.injectKeyboardString(string)
+
+keySyms = {
+	'enter' : 0xff0d,
+	'esc' : 0xff1b,
+	'space' : 0x20
+}
+
+def pressKey(keyName):
+	"""
+	Presses (and releases) the key specified by keyName.
+	keyName is the English name of the key as seen on the keyboard. Ex: 'enter'
+	Names are looked up in the keySyms dict.
+	"""
+	ev = atspi.EventGenerator()
+	keySym = keySyms[keyName.lower()]
+	ev.generateKeyboardEvent(keySym, "", atspi.SPI_KEY_SYM)
+
