@@ -17,10 +17,10 @@ class GoogleFrontPage(Node):
         self.textEntry = self.searchButton.parent.child(roleName='text', debugName='Search String Text Entry')
 
 import dogtail.config
-dogtail.Config.debugSearching=True
+dogtail.config.config.debugSearching=True
 
 # Epiphany doesn't seem to set the sensitivity state on buttons in web pages:
-dogtail.Config.ensureSensitivity=False
+dogtail.config.config.ensureSensitivity=False
 
 wb = EpiphanyApp()
 
@@ -41,7 +41,7 @@ gfp.searchButton.press()
 
 # Scrape out the results:
 frame = gfp.child(roleName='frame')
-results = frame.findAllChildrenSatisfying(GenericPredicate(roleName='text'), recursive=False)
+results = frame.findChildren(predicate.GenericPredicate(roleName='text'), recursive=False)
 for result in results:
     print "Result:"
     print result.text
